AtmsError

Enum AtmsError 

pub enum AtmsError {
    RegisterExistingKey(PublicKey),
    InvalidMerkleProof,
    InvalidKey,
    InvalidPoP,
    NonRegisteredParticipant,
    FoundDuplicates(PublicKey),
    TooMuchOutstandingSigners(usize),
    InvalidSignature,
    InvalidAggregation,
    SerializationError,
    UnexpectedBlstTypes,
}
Errors associated with Atms

Variants



RegisterExistingKey(PublicKey)

This error occurs when one tries to register an existing key



InvalidMerkleProof

The proof that a batch of PKs are members of the MerkleTree is false



InvalidKey

A key submitted for aggregation is invalid.



InvalidPoP

A key submitted contains an invalid PoP.



NonRegisteredParticipant

This error occurs when we try to aggregate a signature from a participant that is not registered



FoundDuplicates(PublicKey)

Duplicate non-signers in signature



TooMuchOutstandingSigners(usize)

Non-signers sum to the given stake, which is more than half of total



InvalidSignature

Underlying signature scheme failed to verify



InvalidAggregation

The given public key does not correspond to the aggregation of the given set of keys



SerializationError

This error occurs when the the serialization of the raw bytes failed



UnexpectedBlstTypes

This error occurs when the underlying function is passed infinity or an element outsize of the group